@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO country
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Country
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Country
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   #possible values
@@ -15,20 +15,28 @@
 #'   charset <- ISOCountry$new(value = "utf8")
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_Country}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/lan/1.0/lan/#element_CountryCode}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOCountry <- R6Class("ISOCountry",
    inherit = ISOCodeListValue,
    private = list(
-     xmlElement = "Country",
-     xmlNamespacePrefix = "GMD"
+     xmlElement = list(
+       "19139" = "Country",
+       "19115-3" = "CountryCode"
+     ),
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "LAN"
+     )
    ),
    public = list(
       
       #'@description Initializes object
-      #'@param xml object of class \link{XMLInternalNode-class}
+      #'@param xml object of class \link[XML]{XMLInternalNode-class}
       #'@param value value
       #'@param description description
       initialize = function(xml = NULL, value, description = NULL){
@@ -40,4 +48,4 @@ ISOCountry <- R6Class("ISOCountry",
 
 ISOCountry$values <- function(labels = FALSE){
   return(ISOCodeListValue$values(ISOCountry, labels))
-}
\ No newline at end of file
+}
