@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO DimensionNameType
-#' @return Object of \code{\link{R6Class}} for modelling an ISO DimensionNameType
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO DimensionNameType
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   #possible values
@@ -15,7 +15,9 @@
 #'   rowType <- ISODimensionNameType$new(value = "row")
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_DimensionNameTypeCode}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/msr/1.0/msr/#element_MD_DimensionNameTypeCode}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -23,12 +25,15 @@ ISODimensionNameType <- R6Class("ISODimensionNameType",
     inherit = ISOCodeListValue,
     private = list(
       xmlElement = "MD_DimensionNameTypeCode",
-      xmlNamespacePrefix = "GMD"
+      xmlNamespacePrefix = list(
+        "19139" = "GMD",
+        "19115-3" = "MSR"
+      )
     ),
     public = list(
       
       #'@description Initializes object
-      #'@param xml object of class \link{XMLInternalNode-class}
+      #'@param xml object of class \link[XML]{XMLInternalNode-class}
       #'@param value value
       #'@param description description
       initialize = function(xml = NULL, value, description = NULL){
@@ -40,4 +45,4 @@ ISODimensionNameType <- R6Class("ISODimensionNameType",
 
 ISODimensionNameType$values <- function(labels = FALSE){
   return(ISOCodeListValue$values(ISODimensionNameType, labels))
-}
\ No newline at end of file
+}
