@@ -4,20 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO measure length distance
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Distance measure
-#' @format \code{\link{R6Class}} object.
-#'
-#' @section Methods:
-#' \describe{
-#'  \item{\code{new(xml,value, uom, useUomURI)}}{
-#'    This method is used to instantiate an ISODistance. The \code{uom} argument represents
-#'    the symbol of unit of measure used. The parameter  \code{useUomURI} can be used to 
-#'    set the uom as URI, its default value is \code{FALSE}.
-#'  }
-#' }
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Distance measure
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @references
-#'  ISO/TS 19103:2005 Geographic information -- Conceptual schema language
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gco/1.0/gco/#element_Distance}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gco/1.0/gco/#element_Distance}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -25,12 +18,15 @@ ISODistance <- R6Class("ISODistance",
    inherit = ISOLength,
    private = list(
      xmlElement = "Distance",
-     xmlNamespacePrefix = "GCO"
+     xmlNamespacePrefix = list(
+       "19139" = "GCO",
+       "19115-3" = "GCO"
+     )
    ),
    public = list(
       
       #'@description Initializes object
-      #'@param xml object of class \link{XMLInternalNode-class}
+      #'@param xml object of class \link[XML]{XMLInternalNode-class}
       #'@param value value
       #'@param uom uom symbol of unit of measure used
       #'@param useUomURI use uom URI. Default is \code{FALSE}
@@ -38,4 +34,4 @@ ISODistance <- R6Class("ISODistance",
        super$initialize(xml = xml, value = value, uom = uom, useUomURI = useUomURI)
      }
    )                        
-)
\ No newline at end of file
+)
