@@ -4,15 +4,17 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO extent
-#' @return Object of \code{\link{R6Class}} for modelling an ISO GeographicBoundingBox
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO GeographicBoundingBox
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   md <- ISOGeographicBoundingBox$new(minx = -180, miny = -90, maxx = 180, maxy = 90)
 #'   xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_EX_GeographicBoundingBox}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gex/1.0/gex/#element_EX_GeographicBoundingBox}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -20,7 +22,10 @@ ISOGeographicBoundingBox <- R6Class("ISOGeographicBoundingBox",
    inherit = ISOGeographicExtent,
    private = list(
      xmlElement = "EX_GeographicBoundingBox",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "GEX"
+     )
    ),
    public = list(
      #'@field westBoundLongitude westBoundLongitude
@@ -33,7 +38,7 @@ ISOGeographicBoundingBox <- R6Class("ISOGeographicBoundingBox",
      northBoundLatitude = NULL,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      #'@param minx minx object of class \link{numeric}
      #'@param miny miny object of class \link{numeric}
      #'@param maxx maxx object of class \link{numeric}
@@ -100,4 +105,4 @@ ISOGeographicBoundingBox <- R6Class("ISOGeographicBoundingBox",
        self$northBoundLatitude <- maxy
      }
    )
-)
\ No newline at end of file
+)
