@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO geometry objects
-#' @return Object of \code{\link{R6Class}} for modelling an ISO GeometricObjects
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO GeometricObjects
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   md <- ISOGeometricObjects$new()
@@ -14,7 +14,9 @@
 #'   xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_GeometricObjects}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/msr/1.0/msr/#element_MD_GeometricObjects}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -22,7 +24,10 @@ ISOGeometricObjects <- R6Class("ISOGeometricObjects",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "MD_GeometricObjects",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MSR"
+     )
    ),
    public = list(
      #'@field geometricObjectType geometricObjectType
@@ -31,7 +36,7 @@ ISOGeometricObjects <- R6Class("ISOGeometricObjects",
      geometricObjectCount = NULL,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -58,4 +63,4 @@ ISOGeometricObjects <- R6Class("ISOGeometricObjects",
       self$geometricObjectCount <- geometricObjectCount
      }
    )                        
-)
\ No newline at end of file
+)
