@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery ObjectiveType
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery ObjectiveType
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery ObjectiveType
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   #possible values
@@ -15,7 +15,9 @@
 #'   survey <- ISOImageryObjectiveType$new(value = "survey")
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_ObjectiveTypeCode}
+#'   
+#'   - 19115-3 \url{https://schemas.isotc211.org/19115/-3/mac/1.0/mac/#element_MI_ObjectiveTypeCode}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -23,12 +25,15 @@ ISOImageryObjectiveType <- R6Class("ISOImageryObjectiveType",
   inherit = ISOCodeListValue,
   private = list(
     xmlElement = "MI_ObjectiveTypeCode",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" = "MAC"
+    )
   ),
   public = list(
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     #'@param value value
     #'@param description description
     initialize = function(xml = NULL, value, description = NULL){
@@ -40,4 +45,4 @@ ISOImageryObjectiveType <- R6Class("ISOImageryObjectiveType",
 
 ISOImageryObjectiveType$values <- function(labels = FALSE){
   return(ISOCodeListValue$values(ISOImageryObjectiveType, labels))
-}
\ No newline at end of file
+}
