@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO keywords
-#' @return Object of \code{\link{R6Class}} for modelling a ISO set of keywords
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling a ISO set of keywords
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   #a basic keyword set
@@ -55,7 +55,9 @@
 #'   inspire_kwd$setThesaurusName(th)
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_Keywords}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mri/1.0/mri/#element_MD_Keywords}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -63,7 +65,10 @@ ISOKeywords <- R6Class("ISOKeywords",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MD_Keywords",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MRI"
+    )
   ),
   public = list(
     #'@field keyword keyword
@@ -74,7 +79,7 @@ ISOKeywords <- R6Class("ISOKeywords",
     thesaurusName = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}    
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}    
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
