@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO legal constraints
-#' @return Object of \code{\link{R6Class}} for modelling an ISO LegalConstraints
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO LegalConstraints
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   #create object
@@ -21,7 +21,9 @@
 #'   xml <- md$encode()
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_LegalConstraints}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mco/1.0/mco/#element_MD_LegalConstraints}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -29,7 +31,10 @@ ISOLegalConstraints <- R6Class("ISOLegalConstraints",
   inherit = ISOConstraints,
   private = list(
     xmlElement = "MD_LegalConstraints",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MCO"
+    )
   ),
   public = list(
     #'@field accessConstraints accessConstraints [0..*]: ISORestriction
@@ -40,7 +45,7 @@ ISOLegalConstraints <- R6Class("ISOLegalConstraints",
     otherConstraints = list(),
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -103,4 +108,4 @@ ISOLegalConstraints <- R6Class("ISOLegalConstraints",
       return(self$delListElement("otherConstraints", constraint))
     }
   )                                          
-)
\ No newline at end of file
+)
