@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO locale
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Locale
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Locale
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   loc <- ISOLocale$new()
@@ -15,7 +15,9 @@
 #'   loc$setCharacterSet("utf8")
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_PT_Locale}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/lan/1.0/lan/#element_PT_Locale}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -23,29 +25,34 @@ ISOLocale <- R6Class("ISOLocale",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "PT_Locale",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "LAN"
+     )
    ),
    public = list(
-     #'@field languageCode languageCode [1..1]: ISOLanguage
+     #'@field languageCode languageCode [1..1]: ISOLanguage (ISO 19139)
      languageCode = NULL,
+     #'@field language language [1..1]: ISOLanguage (ISO 19115-3)
+     language = NULL,
      #'@field country country [0..1]: ISOCountry
      country = NULL,
      #'@field characterEncoding characterEncoding [1..1]: ISOCharacterSet
      characterEncoding = NULL,
 
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      #'@param id id
      #'@param language language
      #'@param country country
-     #'@param encoding encoding
+     #'@param characterEncoding characterEncoding
      initialize = function(xml = NULL, id = NULL, language = NULL,
-                           country = NULL, encoding = NULL){
+                           country = NULL, characterEncoding = NULL){
        super$initialize(xml = xml)
        if(!is.null(id)) self$setId(id)
        if(!is.null(language)) self$setLanguage(language)
        if(!is.null(country)) self$setCountry(country)
-       if(!is.null(encoding)) self$setCharacterSet(encoding)
+       if(!is.null(characterEncoding)) self$setCharacterSet(characterEncoding)
      },
      
      #'@description Set ID
@@ -61,7 +68,14 @@ ISOLocale <- R6Class("ISOLocale",
        if(is(language, "character")){
          language <- ISOLanguage$new(value = language)
        }
-       self$languageCode <- language
+       switch(getMetadataStandard(),
+        "19139" = {
+          self$languageCode <- language
+        },
+        "19115-3" = {
+          self$language = language
+        }
+       )
      },
      
      #'@description Set country
@@ -86,4 +100,4 @@ ISOLocale <- R6Class("ISOLocale",
      }
      
    )                        
-)
\ No newline at end of file
+)
