@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO locale container
-#' @return Object of \code{\link{R6Class}} for modelling an ISO LocaleContainer
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO LocaleContainer
+#' @format \code{\link[R6]{R6Class}} object.
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_PT_LocaleContainer}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/lan/1.0/lan/#element_PT_LocaleContainer}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,10 +18,19 @@ ISOLocaleContainer <- R6Class("ISOLocaleContainer",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "PT_LocaleContainer",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "LAN"
+    )
   ),
   public = list(
     
+    #'@field language language [1..1]: ISOLanguage
+    language = NULL,
+    #'@field country country [0..1]: ISOCountry
+    country = NULL,
+    #'@field characterEncoding character encoding [0..1]: ISOCharacterSet
+    characterEncoding = NULL,
     #'@field description description [1..1]
     description = NULL,
     #'@field locale locale [1..1]
@@ -32,11 +43,50 @@ ISOLocaleContainer <- R6Class("ISOLocaleContainer",
     localisedString = list(),
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
     
+    #'@description Set language
+    #'@param language object of class \link{ISOLanguage} or \link{character}
+    setLanguage = function(language){
+      if(!is(language, "ISOLanguage")){
+        if(is(language,"character")){
+          language = ISOLanguage$new(value = language)
+        }else{
+          stop("The argument 'language' should be an object of class 'ISOLanguage' or 'character'")
+        }
+      }
+      self$language = language
+    },
+    
+    #'@description Set country
+    #'@param country object of class \link{ISOCountry} or \link{character}
+    setCountry = function(country){
+      if(!is(country, "ISOCountry")){
+        if(is(country,"character")){
+          country = ISOCountry$new(value = country)
+        }else{
+          stop("The argument 'country' should be an object of class 'ISOCountry' or 'character'")
+        }
+      }
+      self$country = country
+    },
+    
+    #'@description Set character encoding
+    #'@param characterEncoding object of class \link{ISOCharacterSet} or \link{character}
+    setCharacterEncoding = function(characterEncoding){
+      if(!is(characterEncoding, "ISOCharacterSet")){
+        if(is(characterEncoding,"character")){
+          characterEncoding = ISOCharacterSet$new(value = characterEncoding)
+        }else{
+          stop("The argument 'characterEncoding' should be an object of class 'ISOCharacterSet' or 'character'")
+        }
+      }
+      self$characterEncoding = characterEncoding
+    },
+    
     #'@description Set description
     #'@param description description
     #'@param locales list of localized texts. Default is \code{NULL}
@@ -77,22 +127,42 @@ ISOLocaleContainer <- R6Class("ISOLocaleContainer",
     },
     
     #'@description Adds responsible party
-    #'@param responsibleParty object of class \link{ISOResponsibleParty}
+    #'@param responsibleParty object of class \link{ISOResponsibleParty} (in ISO 19139) or 
+    #'\link{ISOResponsibility} (in ISO 19115-3)
     #'@return \code{TRUE} if added, \code{FALSE} otherwise
     addResponsibleParty = function(responsibleParty){
-      if(!is(responsibleParty, "ISOResponsibleParty")){
-        stop("The argument 'responsibleParty' should be an object of class 'ISOResponsibleParty'")
-      }
+      switch(getMetadataStandard(),
+       "19139" = {
+         if(!is(responsibleParty, "ISOResponsibleParty")){
+           stop("The argument 'responsibleParty' should be an object of class 'ISOResponsibleParty'")
+         }
+       },
+       "19115-3" = {
+         if(!is(responsibleParty, "ISOResponsibility")){
+           stop("The argument 'responsibleParty' should be an object of class 'ISOResponsibility'")
+         }
+       }
+      )
       return(self$addListElement("responsibleParty", responsibleParty))
     },
     
     #'@description Deletes responsible party
-    #'@param responsibleParty object of class \link{ISOResponsibleParty}
+    #'@param responsibleParty object of class \link{ISOResponsibleParty} (in ISO 19139) or 
+    #'\link{ISOResponsibility} (in ISO 19115-3)
     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
     delResponsibleParty = function(responsibleParty){
-      if(!is(responsibleParty, "ISOResponsibleParty")){
-        stop("The argument 'responsibleParty' should be an object of class 'ISOResponsibleParty'")
-      }
+      switch(getMetadataStandard(),
+       "19139" = {
+         if(!is(responsibleParty, "ISOResponsibleParty")){
+           stop("The argument 'responsibleParty' should be an object of class 'ISOResponsibleParty'")
+         }
+       },
+       "19115-3" = {
+         if(!is(responsibleParty, "ISOResponsibility")){
+           stop("The argument 'responsibleParty' should be an object of class 'ISOResponsibility'")
+         }
+       }
+      )
       return(self$delListElement("responsibleParty", responsibleParty))
     },
     
@@ -112,4 +182,4 @@ ISOLocaleContainer <- R6Class("ISOLocaleContainer",
       return(self$delListElement("localisedString", str))
     }
   )                        
-)
\ No newline at end of file
+)
