@@ -4,15 +4,17 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO localised character string
-#' @return Object of \code{\link{R6Class}} for modelling an ISO LocalisedCharacterString
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO LocalisedCharacterString
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   str <- ISOLocalisedCharacterString$new(locale = "FR", value = "ma description")
 #'   str$encode()
 #' 
 #' @references
-#'  ISO/TS 19103:2005 Geographic information -- Conceptual schema language
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_LocalisedCharacterString}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/lan/1.0/lan/#element_LocalisedCharacterString}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -20,12 +22,15 @@ ISOLocalisedCharacterString <- R6Class("ISOLocalisedCharacterString",
   inherit = ISOBaseCharacterString,
   private = list(
     xmlElement = "LocalisedCharacterString",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "LAN"
+    )
   ),
   public = list(
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     #'@param locale locale
     #'@param value value
     initialize = function(xml = NULL, locale = NULL, value){
@@ -35,4 +40,4 @@ ISOLocalisedCharacterString <- R6Class("ISOLocalisedCharacterString",
       }
     }
   )                        
-)
\ No newline at end of file
+)
