@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO medium
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Citation
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Citation
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'  md <- ISOMedium$new()
@@ -18,7 +18,9 @@
 #'  xml <- md$encode()
 #'  
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_Medium}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrd/1.0/mrd/#element_MD_Medium}  
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -26,7 +28,10 @@ ISOMedium<- R6Class("ISOMedium",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MD_Medium",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MRD"
+    )
   ),
   public = list(
     #'@field name name
@@ -43,7 +48,7 @@ ISOMedium<- R6Class("ISOMedium",
     mediumNote = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
