@@ -4,15 +4,17 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO browse graphic
-#' @return Object of \code{\link{R6Class}} for modelling an ISO ScopeDescription
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO ScopeDescription
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'  md <- ISOScopeDescription$new()
 #'  xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_ScopeDescription}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mcc/1.0/mcc/#element_MD_ScopeDescription}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -20,7 +22,10 @@ ISOScopeDescription <- R6Class("ISOScopeDescription",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MD_ScopeDescription",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MCC"
+    )
   ),
   public = list(
     #'@field attributes attributes [1..*]
@@ -37,7 +42,7 @@ ISOScopeDescription <- R6Class("ISOScopeDescription",
     other = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -96,4 +101,4 @@ ISOScopeDescription <- R6Class("ISOScopeDescription",
       self$other <- other
     }
   )                        
-)
\ No newline at end of file
+)
