@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO temporal extent
-#' @return Object of \code{\link{R6Class}} for modelling an ISO TemporalExtent
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO TemporalExtent
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'    te <- ISOTemporalExtent$new()
@@ -15,7 +15,9 @@
 #'    te$setTimePeriod(tp)
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_EX_TemporalExtent}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gex/1.0/gex/#element_EX_TemporalExtent}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -23,14 +25,17 @@ ISOTemporalExtent <- R6Class("ISOTemporalExtent",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "EX_TemporalExtent",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "GEX"
+    )
   ),
   public = list(
     #'@field extent extent
     extent = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}  
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}  
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -53,4 +58,4 @@ ISOTemporalExtent <- R6Class("ISOTemporalExtent",
       self$extent = timePeriod
     }
   )                                          
-)
\ No newline at end of file
+)
