@@ -56,7 +56,7 @@ test_that("encoding",{
   md2 <- ISOBoundFeatureAttribute$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOAbstractObject$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2, "xml"))
   
 })
 
@@ -164,6 +164,6 @@ test_that("encoding - i18n",{
   md2 <- ISOBoundFeatureAttribute$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOAbstractObject$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2, "xml"))
   
 })
\ No newline at end of file
