@@ -14,7 +14,7 @@ test_that("encoding",{
   dq <- ISODataQuality$new()
   
   #add scope
-  scope <- ISOScope$new()
+  scope <- ISODataQualityScope$new()
   scope$setLevel("dataset")
   dq$setScope(scope)
   
@@ -57,7 +57,7 @@ test_that("encoding - i18n",{
   dq <- ISODataQuality$new()
   
   #add scope
-  scope <- ISOScope$new()
+  scope <- ISODataQualityScope$new()
   scope$setLevel("dataset")
   dq$setScope(scope)
   
