@@ -10,13 +10,12 @@ context("ISODefinitionReference")
 
 test_that("encoding",{
   testthat::skip_on_cran()
-  testthat::skip_on_travis()
   #encoding
   md <- ISODefinitionReference$new()
   md$setSourceIdentifier("identifier")
   citation <- ISOCitation$new()
   citation$setTitle("title")
-  citation$setAlternateTitle("alternate title")
+  citation$addAlternateTitle("alternate title")
   d <- ISODate$new()
   d$setDate(ISOdate(2017,1,1))
   d$setDateType("creation")
