@@ -10,7 +10,6 @@ context("ISOMimeFileType")
 
 test_that("encoding",{
   testthat::skip_on_cran()
-  testthat::skip_on_travis()
   #encoding
   md <- ISOMimeFileType$new(type = "somemimetype", name = "Mime type name")
   xml <- md$encode()
@@ -22,4 +21,22 @@ test_that("encoding",{
   
   expect_true(ISOAbstractObject$compare(md, md2))
   
+})
+
+test_that("encoding",{
+  testthat::skip_on_cran()
+  
+  #build from
+  md <- ISOMimeFileType$buildFrom("gpkg")
+  expect_equal(md$attrs$type, "application/geopackage+sqlite3")
+  xml <- md$encode()
+  expect_is(xml, "XMLInternalNode")
+  
+  #decoding
+  md2 <- ISOMimeFileType$new(xml = xml)
+  xml2 <- md2$encode()
+  
+  expect_true(ISOAbstractObject$compare(md, md2))
+  
+  
 })
\ No newline at end of file
